@@ -20,7 +20,7 @@ def get_collection_count_validator() -> Validator:
     collection_count_validator: Validator = Validator.from_callable(
         _validate_collection_count,
         "Number of collections must be between 2 and 32",
-        move_cursor_to_end=True
+        move_cursor_to_end=True,
     )
     return collection_count_validator
 
@@ -29,7 +29,7 @@ def get_pick_validator() -> Validator:
     pick_validator: Validator = Validator.from_callable(
         _validate_picks,
         "One or more picks is invalid. Picks must be ints between 1 and 270.",
-        move_cursor_to_end=True
+        move_cursor_to_end=True,
     )
     return pick_validator
 
@@ -38,6 +38,6 @@ def get_collection_name_validator() -> Validator:
     collection_name_validator: Validator = Validator.from_callable(
         _validate_collection_name,
         "Collection name/identifier cannot be empty",
-        move_cursor_to_end=True
+        move_cursor_to_end=True,
     )
     return collection_name_validator
